@@ -100,10 +100,20 @@ class WidgetBuilder(DockWidgetBase):
         self.scroll_layout.setSpacing(4)
         self.scroll_layout.setAlignment(QtCore.Qt.AlignTop)
         self.scroll_widget.setLayout(self.scroll_layout)
+        # Context menu
+        self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.customContextMenuRequested.connect(self.context_menu)
 
         # update
         self.update_window()
 
+    def context_menu(self):
+        menu = QtWidgets.QMenu(self)
+        refresh_action = menu.addAction('Refresh')
+        refresh_action.triggered.connect(self.update_window)
+        menu.addAction(self.main_window.execute_actions.wt_recomp_action)
+        menu.popup(QtGui.QCursor.pos())
+
     def show(self):
         super(WidgetBuilder, self).show()
         self.update_window()
@@ -854,8 +864,11 @@ class Button(QtWidgets.QPushButton):
                 attr_name=self.INPUT_LIST_ATTR,
                 layer=None,
                 data_state=DATA_STATE.CACHED)
-        items = ast.literal_eval(input_value) if input_value else []
-
+        if (not isinstance(input_value, str) and
+                isinstance(input_value, Iterable)):
+            items = input_value
+        else:
+            items = []
         # selector dialog
         screen = QtWidgets.QApplication.desktop().screenNumber(
             QtWidgets.QApplication.desktop().cursor().pos())
